/* vi:cino=>4,g4,h4,+4,c1,C4,(4,u4,\:0,l1:shiftwidth=4:softtabstop=4:expandtab
 */
/*

Copyright (c) 2009, SFB/TR-55
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

  * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

  * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#ifndef GS_AUTO_H_
#define GS_AUTO_H_

/** 
 * @file
 * The @a libgsauto library provides (when linking) automated
 * calling of a constructor function that will install an exit handler,
 * a handler for the @a SIGIO signal, and properly register the
 * calling process with the global signals device.
 * Futhermore (and new in version 4.3.1) if the environemt variable
 * @a GSTREECHECK is set, the process will automatically perform a
 * check of the global signals tree at startup.
 * If the content of @a GSTREECHECK is not empty, it will be parsed
 * (using sscanf) if it represents an integer value. That value is
 * used as the verbosity parameter of @a gsTreeCheck() from the
 * @a libgsguru library. (0 means no output, 1 some output, and
 * 2 means lots of output.) The default value (if @a GSTREECHECK is
 * empty or if sscanf fails) is 2.
 */

#define GS_AUTO_VERSION "libgsauto-4.3.1"

/** Return the automatic handle.
 * @a libgsauto automatically opens a handle to the GS device,
 * and stores it in a static variable. The handle is a file
 * descriptor to the opened GS device. 
 * @a gsAutoHandle returns the file descriptor number (the handle).
 */
int gsAutoHandle();

/** GS linker dummy.
 * This function does nothing, but forces the linker
 * to link with this library.
 */
void gs_globsig();

#endif /* defined GS_AUTO_H_ */

